@@ -40,8 +40,10 @@ exports.listServices = function (){
     url: url,
     form:{
       "access_token": config.access_token
-    }
+    },
+    timeout:20000
   };
+
   var response = request(options);
   return response.then(function (r) {
     var res  = r[0].req.res;
